@@ -5,7 +5,6 @@ from django.contrib.auth.decorators import login_required
 from django.urls import re_path
 from django.urls import reverse_lazy
 
-from core_dashboard_app.views.common import views as dashboard_app_common_views
 from core_dashboard_common_app.views.common import (
     ajax,
     views as dashboard_common_app_common_views,
@@ -13,11 +12,17 @@ from core_dashboard_common_app.views.common import (
 from core_dashboard_common_app.views.common.views import (
     UserDashboardPasswordChangeFormView,
 )
+from core_main_app.settings import INSTALLED_APPS
 from core_main_app.views.common.ajax import EditTemplateVersionManagerView
+from core_dashboard_app.views.common import views as dashboard_app_common_views
 
 urlpatterns = [
     # Common
-    re_path(r"^$", dashboard_common_app_common_views.home, name="core_dashboard_home"),
+    re_path(
+        r"^$",
+        dashboard_common_app_common_views.home,
+        name="core_dashboard_home",
+    ),
     re_path(
         r"^my-profile$",
         dashboard_common_app_common_views.my_profile,
@@ -37,14 +42,18 @@ urlpatterns = [
         name="core_dashboard_profile_change_password",
     ),
     re_path(
-        r"^delete-document", ajax.delete_document, name="core_dashboard_delete_document"
+        r"^delete-document",
+        ajax.delete_document,
+        name="core_dashboard_delete_document",
     ),
     re_path(
         r"^change-owner",
         ajax.change_owner_document,
         name="core_dashboard_change_owner_document",
     ),
-    re_path(r"^edit-record", ajax.edit_record, name="core_dashboard_edit_record"),
+    re_path(
+        r"^edit-record", ajax.edit_record, name="core_dashboard_edit_record"
+    ),
     # User
     re_path(
         r"^records$",
@@ -117,11 +126,18 @@ urlpatterns = [
         ),
         name="core_dashboard_app_edit_template",
     ),
-    re_path(
-        r"^type/(?P<pk>[\w-]+)/edit/$",
-        EditTemplateVersionManagerView.as_view(
-            success_url=reverse_lazy("core_dashboard_types")
-        ),
-        name="core_dashboard_app_edit_type",
-    ),
 ]
+
+
+if "core_composer_app" in INSTALLED_APPS:
+    from core_composer_app.views.user.ajax import EditTypeVersionManagerView
+
+    urlpatterns.append(
+        re_path(
+            r"^type/(?P<pk>[\w-]+)/edit/$",
+            EditTypeVersionManagerView.as_view(
+                success_url=reverse_lazy("core_dashboard_types")
+            ),
+            name="core_dashboard_app_edit_type",
+        ),
+    )
